#include <QGraphicsItem>
#include <QApplication>
#include <QGraphicsScene>
#include <QGraphicsView>
#include <QTime>
#include <QScrollBar>
#include <QDebug>
#include <QStyleOptionGraphicsItem>
#include <math.h>

class SignalItem : public QGraphicsItem
{    
public:
    SignalItem(int nr)
    {
        setFlags(QGraphicsItem::ItemUsesExtendedStyleOption);
        nr_ = nr;
        fr_ = 20;
        bg_ = Qt::white;
    }
    
    QRectF boundingRect() const
    {
        return QRectF(0, nr_*50, 10000, 50);
    }
    
    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0)
    {
        painter->fillRect(option->exposedRect, bg_);
        float prevY = sin((int(option->exposedRect.left()) - 1)/fr_)*10 + 25 + nr_*50;
        for (int x = int(option->exposedRect.left()); x < int(option->exposedRect.right()); x++) {
            float y = sin(x/fr_)*10 + 25 + nr_*50;
            painter->drawLine(x-1, prevY, x, y);
            prevY = y;
        }
    }
private:
    int nr_;
    float fr_;
    QColor bg_;
};

class Dummy : public QObject
{
public:
    Dummy()
    {
        scene_ = new QGraphicsScene();

        for (int i=0; i < 40; i++)
            scene_->addItem(new SignalItem(i));

        view_ = new QGraphicsView(scene_);
        view_->show();

        startTimer(25);
        x_ = 0;
    }

    void timerEvent(QTimerEvent* event)
    {
        x_ += 5;
        view_->horizontalScrollBar()->setValue(x_);
        QTime currentTime = QTime::currentTime();
        if (lastTimerEvent_.isValid())
            qDebug() << lastTimerEvent_.msecsTo(currentTime);
        lastTimerEvent_ = currentTime;
    }
private:
    QGraphicsScene* scene_;
    QGraphicsView* view_;
    QTime lastTimerEvent_;
    int x_;
};

int main(int argc, char* argv[])
{
  QApplication* app = new QApplication(argc, argv);
  Dummy* d = new Dummy();
  return app->exec();
}

